pub enum OpenableRequest {
Open {
path: String,
flags: Flags,
options: Options,
object: Channel,
control_handle: OpenableControlHandle,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: OpenableControlHandle,
method_type: MethodType,
},
}Expand description
Openable defines a node which is capable of opening other objects.
Variants
Open
Open (or create) a node relative to this directory. Any errors are communicated via an
epitaph sent on the object channel.
Errors:
ZX_ERR_BAD_PATHifpathis invalid- See
Flagsfor other errors which may be communicated based onflags
Fields

control_handle: OpenableControlHandle#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: OpenableControlHandle
method_type: MethodTypeImplementations