pub struct FileInfo {
pub is_append: Option<bool>,
pub observer: Option<Event>,
pub stream: Option<Stream>,
pub attributes: Option<NodeAttributes2>,
/* private fields */
}Expand description
Auxiliary data for the file representation of a node.
Fields
is_append: Option<bool>True if the file is opened in append mode. In append mode, the seek offset is moved to the end before every write, the two steps performed in an atomic manner.
observer: Option<Event>An optional event which transmits information about an object’s readability or writability. This event relays information about the underlying object, not the capability granted to client: this event may be signalled “readable” on a connection that does not have the capability to read.
This event will be present if the following conditions are met:
- The
available_operationson the file connection is not empty. - The filesystem supports signalling readability/writability events.
The FileSignal values may be observed on this event.
stream: Option<Stream>An optional stream object, which can be used to read to and write from the file more quickly than with fidl.
The channel for the file must be held open while the stream is in use. Using a stream object that has outlived the channel it came from may result in failures or unexpected results.
attributes: Option<NodeAttributes2>Requested attributes for the file. This is only populated if requested.