pub struct Flags(/* private fields */);Expand description
Flags used to specify how a node should be opened. Note that ranges of bits are reserved for specific use cases:
- Bits 1-16: Permission flags
PERM_*(e.g. [Flags.PERM_READ_BYTES]). - Bits 17-32: POSIX compatibile
O_*flags (e.g. [Flags.FILE_TRUNCATE] orO_TRUNC). - Bits 33-64: Fuchsia-specific flags.
Implementations
Sourceimpl Flags
impl Flags
Sourcepub const PERM_CONNECT: Flags
pub const PERM_CONNECT: Flags
Allows opening child nodes with [PROTOCOL_SERVICE].
Sourcepub const PERM_READ_BYTES: Flags
pub const PERM_READ_BYTES: Flags
Read byte contents of a file.
Sourcepub const PERM_WRITE_BYTES: Flags
pub const PERM_WRITE_BYTES: Flags
Write byte contents to a file.
Sourcepub const PERM_EXECUTE: Flags
pub const PERM_EXECUTE: Flags
Execute byte contents of a file.
Sourcepub const PERM_GET_ATTRIBUTES: Flags
pub const PERM_GET_ATTRIBUTES: Flags
Get/query attributes of a node.
Sourcepub const PERM_UPDATE_ATTRIBUTES: Flags
pub const PERM_UPDATE_ATTRIBUTES: Flags
Set/update attributes of a node.
Sourcepub const PERM_ENUMERATE: Flags
pub const PERM_ENUMERATE: Flags
Enumerate (list) directory entries.
Sourcepub const PERM_TRAVERSE: Flags
pub const PERM_TRAVERSE: Flags
Allow opening a child node with a node protocol. Must be specified with PERM_ENUMERATE
otherwise requests will fail with ZX_ERR_INVALID_ARGS.
Sourcepub const PERM_MODIFY_DIRECTORY: Flags
pub const PERM_MODIFY_DIRECTORY: Flags
Modify directory entries (create/rename/link/unlink). Must be specified with
PERM_ENUMERATE otherwise requests will fail with ZX_ERR_INVALID_ARGS.
Sourcepub const PERM_INHERIT_WRITE: Flags
pub const PERM_INHERIT_WRITE: Flags
Inherit write permissions when available (PERM_WRITE_BYTES, PERM_UPDATE_ATTRIBUTES,
PERM_MODIFY_DIRECTORY, /// PERM_ENUMERATE). Servers must ensure this flag is removed
if the parent connection lacks any of these rights. See INHERITED_WRITE_PERMISSIONS
for the exact set of permissions that will be inherited.
Sourcepub const PERM_INHERIT_EXECUTE: Flags
pub const PERM_INHERIT_EXECUTE: Flags
Inherit execute permission when available (PERM_EXECUTE). Servers must ensure this flag is removed if the parent connection lacks PERM_EXECUTE.
Sourcepub const PROTOCOL_SERVICE: Flags
pub const PROTOCOL_SERVICE: Flags
Connect to the underlying protocol if this is a service node. The caller must determine the
correct protocol to use (e.g. based on path). Unless used with [PROTOCOL_NODE], specifying
other flags with the request will fail with ZX_ERR_INVALID_ARGS.
Sourcepub const PROTOCOL_NODE: Flags
pub const PROTOCOL_NODE: Flags
Connect to the underlying node. Takes precedence over other protocols. If other PROTOCOL_*
are specified, they will be used to validate the target node type. Requests will fail with
ZX_ERR_INVALID_ARGS if flags other than PROTOCOL_* and [FLAG_SEND_REPRESENTATION] are
specified. Equivalent to POSIX O_PATH.
Sourcepub const PROTOCOL_DIRECTORY: Flags
pub const PROTOCOL_DIRECTORY: Flags
Caller accepts [fuchsia.io/Directory] protocol. Equivalent to POSIX O_DIRECTORY.
Sourcepub const PROTOCOL_FILE: Flags
pub const PROTOCOL_FILE: Flags
Caller accepts [fuchsia.io/File] protocol.
Sourcepub const PROTOCOL_SYMLINK: Flags
pub const PROTOCOL_SYMLINK: Flags
Caller accepts [fuchsia.io/Symlink] protocol.
Sourcepub const FLAG_SEND_REPRESENTATION: Flags
pub const FLAG_SEND_REPRESENTATION: Flags
Caller requests a [fuchsia.io/Node.OnRepresentation] event on success.
Sourcepub const FLAG_MAYBE_CREATE: Flags
pub const FLAG_MAYBE_CREATE: Flags
Create a new object if one doesn’t exist, otherwise open an existing object. If set, a
single PROTOCOL_* flag must be set indicating the type of object to create. Equivalent
to POSIX O_CREAT.
Sourcepub const FLAG_MUST_CREATE: Flags
pub const FLAG_MUST_CREATE: Flags
Create a new object if one doesn’t exist, otherwise fail the request with
ZX_ERR_ALREADY_EXISTS. If set, a single PROTOCOL_* flag must be set indicating the type
of object to create. Takes precedence over [FLAG_MAYBE_CREATE]. Equivalent to POSIX
O_EXCL.
Sourcepub const FLAG_CREATE_AS_UNNAMED_TEMPORARY: Flags
pub const FLAG_CREATE_AS_UNNAMED_TEMPORARY: Flags
Create a new unnamed temporary object. The object is temporary until it is linked to the
filesystem. If specified with FLAG_TEMPORARY_AS_NOT_LINKABLE, then the created object is
not linkable. If this flag is set:
pathspecified in [fuchsia.io/Directory.Open] refers to the path of the directory which the new object will be created in,- A
PROTOCOL_*flag is set to indicate the type of object to be created. Currently, this is only supported when specified withPROTOCOL_FILE, in which case, it is equivalent to LinuxO_TMPFILE. FLAG_MAYBE_CREATEwill be ignored.
Sourcepub const FILE_APPEND: Flags
pub const FILE_APPEND: Flags
Open the file in append mode. The seek pointer will be moved to end-of-file (EOF)
before all writes. Equivalent to POSIX O_APPEND.
Sourcepub const FILE_TRUNCATE: Flags
pub const FILE_TRUNCATE: Flags
Truncate the file to zero length upon opening it. Equivalent to POSIX O_TRUNC.
Sourceimpl Flags
impl Flags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Flags>
pub const fn from_bits(bits: u64) -> Option<Flags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Flags
pub const fn from_bits_truncate(bits: u64) -> Flags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Flags
pub const fn from_bits_retain(bits: u64) -> Flags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Flags>
pub fn from_name(name: &str) -> Option<Flags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Flags) -> bool
pub const fn intersects(&self, other: Flags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Flags) -> bool
pub const fn contains(&self, other: Flags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Flags)
pub fn remove(&mut self, other: Flags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Flags)
pub fn toggle(&mut self, other: Flags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Flags, value: bool)
pub fn set(&mut self, other: Flags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Flags) -> Flags
pub const fn intersection(self, other: Flags) -> Flags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Flags) -> Flags
pub const fn union(self, other: Flags) -> Flags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Flags) -> Flags
pub const fn difference(self, other: Flags) -> Flags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Flags) -> Flags
pub const fn symmetric_difference(self, other: Flags) -> Flags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Flags
pub const fn complement(self) -> Flags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Flags
impl Flags
Sourcepub const fn iter(&self) -> Iter<Flags>
pub const fn iter(&self) -> Iter<Flags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Flags>
pub const fn iter_names(&self) -> IterNames<Flags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Flags
impl Flags
pub fn from_bits_allow_unknown(bits: u64) -> Flags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u64