ImmutableNodeAttributes

Struct ImmutableNodeAttributes 

pub struct ImmutableNodeAttributes {
    pub protocols: Option<NodeProtocolKinds>,
    pub abilities: Option<Operations>,
    pub content_size: Option<u64>,
    pub storage_size: Option<u64>,
    pub link_count: Option<u64>,
    pub id: Option<u64>,
    pub change_time: Option<u64>,
    pub options: Option<VerificationOptions>,
    pub root_hash: Option<Vec<u8>>,
    pub verity_enabled: Option<bool>,
    /* private fields */
}

Fields

protocols: Option<NodeProtocolKinds>

Describes the kinds of representations supported by the node. Note: This is not the result of the connection-time negotiation, which is conveyed via representation.

abilities: Option<Operations>

Describes the kinds of operations supported by the node. Note: This is distinct from the rights used at connection time.

content_size: Option<u64>

Node size, in bytes.

storage_size: Option<u64>

Space needed to store the node (possibly larger than size), in bytes.

link_count: Option<u64>

Number of hard links to the node. It must be at least one.

id: Option<u64>

An ID for the node. See Id. This id should be unique among all entries of a directory.

change_time: Option<u64>

Time of last change to the metadata in nanoseconds since the Unix epoch, UTC.

options: Option<VerificationOptions>

Contains the verification options for verity-enabled files.

root_hash: Option<Vec<u8>>

The root hash for the file. Not all filesystems support this across all files.

verity_enabled: Option<bool>

True if this file is verity-enabled.