pub struct OpenableOpenRequest {
pub path: String,
pub flags: Flags,
pub options: Options,
pub object: Channel,
}Fields
path: Stringflags: Flagsoptions: Optionsobject: ChannelTrait Implementations
Sourceimpl Debug for OpenableOpenRequest
impl Debug for OpenableOpenRequest
Sourceimpl Decode<OpenableOpenRequest, DefaultFuchsiaResourceDialect> for OpenableOpenRequest
impl Decode<OpenableOpenRequest, DefaultFuchsiaResourceDialect> for OpenableOpenRequest
Sourceimpl<T0: Encode<BoundedString<4095>, DefaultFuchsiaResourceDialect>, T1: Encode<Flags, DefaultFuchsiaResourceDialect>, T2: Encode<Options, DefaultFuchsiaResourceDialect>, T3: Encode<HandleType<Channel, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<OpenableOpenRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2, T3)
impl<T0: Encode<BoundedString<4095>, DefaultFuchsiaResourceDialect>, T1: Encode<Flags, DefaultFuchsiaResourceDialect>, T2: Encode<Options, DefaultFuchsiaResourceDialect>, T3: Encode<HandleType<Channel, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<OpenableOpenRequest, DefaultFuchsiaResourceDialect> for (T0, T1, T2, T3)
Sourceimpl PartialEq for OpenableOpenRequest
impl PartialEq for OpenableOpenRequest
Sourceimpl ResourceTypeMarker for OpenableOpenRequest
impl ResourceTypeMarker for OpenableOpenRequest
Sourcetype Borrowed<'a> = &'a mut OpenableOpenRequest
type Borrowed<'a> = &'a mut OpenableOpenRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for OpenableOpenRequest
impl TypeMarker for OpenableOpenRequest
Sourcetype Owned = OpenableOpenRequest
type Owned = OpenableOpenRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for OpenableOpenRequest
impl StructuralPartialEq for OpenableOpenRequest