pub struct OpenableProxy { /* private fields */ }Implementations
Sourceimpl OpenableProxy
impl OpenableProxy
Sourcepub fn take_event_stream(&self) -> OpenableEventStream
pub fn take_event_stream(&self) -> OpenableEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn open(
&self,
path: &str,
flags: Flags,
options: &Options,
object: Channel,
) -> Result<(), Error>
pub fn open( &self, path: &str, flags: Flags, options: &Options, object: Channel, ) -> Result<(), Error>
Open (or create) a node relative to this directory. Any errors are communicated via an
epitaph sent on the object channel.
Errors:
ZX_ERR_BAD_PATHifpathis invalid- See
Flagsfor other errors which may be communicated based onflags