pub struct OpenableSynchronousProxy { /* private fields */ }Implementations
Sourceimpl OpenableSynchronousProxy
impl OpenableSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<OpenableEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<OpenableEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn open(
&self,
path: &str,
flags: Flags,
options: &Options,
object: Channel,
) -> Result<(), Error>
pub fn open( &self, path: &str, flags: Flags, options: &Options, object: Channel, ) -> Result<(), Error>
Open (or create) a node relative to this directory. Any errors are communicated via an
epitaph sent on the object channel.
Errors:
ZX_ERR_BAD_PATHifpathis invalid- See
Flagsfor other errors which may be communicated based onflags