Options

Struct Options 

pub struct Options {
    pub attributes: Option<NodeAttributesQuery>,
    pub create_attributes: Option<MutableNodeAttributes>,
    /* private fields */
}
Options which can be used when opening nodes. Unlike Flags, these options are designed for specific use cases (e.g. to reduce round-trip latency when requesting attributes).

Fields

attributes: Option<NodeAttributesQuery>

Request a set of attributes to be sent with the OnRepresentation response. Has no effect if Flags.FLAG_SEND_REPRESENTATION is not set.

create_attributes: Option<MutableNodeAttributes>

Request a set of attributes to be set atomically when creating a new object. Requests will fail with ZX_ERR_INVALID_ARGS if neither Flags.FLAG_MAYBE_CREATE nor Flags.FLAG_MUST_CREATE are set (i.e. the creation is mode is Never).