SymlinkInfo

Struct SymlinkInfo 

pub struct SymlinkInfo {
    pub target: Option<Vec<u8>>,
    pub attributes: Option<NodeAttributes2>,
    /* private fields */
}

Fields

target: Option<Vec<u8>>

The symbolic link has no meaning on the server; the client is free to interpret the target however it chooses.

attributes: Option<NodeAttributes2>

Requested attributes for the symbolic link. This is only populated if requested.